<?php
// Grid Solver (c) Dominic Szablewski - www.phoboslab.org

require_once( 'gridsolver.php' );
require_once( 'createthumb.php' );

// Load the images. Normally you'd want to load images from a database or some 
// other meaningfull resource - here we'll just load all JPEGs from the image/ 
// directory
$files = glob('images/*.jpg');

// Create our initial thumbs array. All we need is the name of the image and a score.
// Since we don't have a voting-score or any other hint on importance we'll just 
// randomly generate a score for every image.
$thumbs = array();
foreach( $files as $file ) {
	$name = basename( $file );
	$thumbs[] = array(
		'name' => $name,
		'score' => rand( 0, 100 )
	);
	
	// Let's see if we allready have all thumbnails for this image in every size.
	// If not, create them!
	foreach( GridSolver::$settings['classes'] as $gc ) {
		if( !file_exists( 'thumbs/'.$gc['dir'].'/'.$name ) ) {
			createThumb( 
				'images/'.$name, 
				'thumbs/'.$gc['dir'].'/'.$name,
				$gc['width'] * GridSolver::$settings['gridSize'] - GridSolver::$settings['borderWidth'], 
				$gc['height'] * GridSolver::$settings['gridSize'] - GridSolver::$settings['borderWidth']
			);
		}
	}
}


// Now load the Grid-Solver and feed it our thumbs array.
// The Grid-Solver will work on the actual array passed to it. It won't create
// a copy of the thumbs array for performance reasons.

$gs = new GridSolver( 24 );
$gs->solve( $thumbs );

// Okay, the Grid-Solver has processed our thumbs. Now every element in the thumb 
// array has the following keys:
// name and score - just as in our input
// dir - directory name for the thumb in a specific size, eg. 64x96
// top - y position of the thumbnail in pixels
// left - x position of the thumbnail in pixels
	
	
?><!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
	<title>Grid-Solver Demo by Dominic Szablewski</title>
	<link rel="stylesheet" type="text/css" href="styles.css"/>
	<script type="text/javascript" src="gridsolver.js"></script>
</head>
<body >

<div id="imageGrid" style="height:<?php echo $gs->height;?>px">
<?php
// This foreach loop will simply echo the HTML for each thumb
foreach( $thumbs as $thumb ) {
	echo '<div class="'.$thumb['class'].'" style="left:'.$thumb['left'].'px;top:'.$thumb['top'].'px;">'
			.'<a class="thumb" href="images/'.$thumb['name'].'">'
				.'<img src="thumbs/'.$thumb['dir'].'/'.$thumb['name'].'" alt=""/>'
			.'</a>'
		."</div>\n";
}
?>
</div>

<script type="text/javascript">
	// AFTER the imageGrid DIV is completly loaded, we can tell our Javascript 
	// Grid Solver to take over. Instead of heaving this line here in the HTML, 
	// you could also use something like DOMReady, but I figured this will work
	// just fine.
	gridSolve( 'imageGrid' ); 
</script>

</body>
</html>